@@ -28,7 +28,7 @@ def main():
     parser.add_argument('--version', help="Shows the current version", action='version', version=version)
     args = parser.parse_args()
 
-    segmentation = segment.apply(only_CPU=args.CPU)
+    segment.apply(input=args.input,output=args.output,only_CPU=args.CPU)
 
 
 
